/* $Header: /cvs/gnome/gIDE/src/gide-windows.h,v 1.5 2001/07/20 04:23:21 jpr Exp $ */
/* gIDE
 * Copyright (C) 1998-2000 JP Rosevear
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#ifndef GIDE_WINDOWS_H
#define GIDE_WINDOWS_H

#include "gI_window.h"
#include "e-splash.h"

/* Individual window functions */
GideWindow *gide_window_new (ESplash *splash);

/* Functions the apply to all windows */
void gide_set_all_window_cfg_values (void);

#endif

